/*
Here is where things might get a little more complicated
if you don't know what you're doing. You should know
what a HUD is by now and also how to create and use
them.

In this section I will explain to you how you can use
HUDs as your own version of a switch proc to select
a certain choice. The outcome of what I will show you
will be a small cursor that you move to choose either a
white or a black square. You will move the cursor
with the Up or Down keys and select your color with
Enter.

1. Let's make some HUDs first.
_______________________________

We'll start out here by making the three HUDs that
we'll be using. You shouldn't need much explaination
for this if you are reading this section. If you do
need explaination, read the "Huds For Beginners" section.
*/

obj
	icon='Huds.dmi'
	Black
		icon_state="black"
		New(client/C)
			screen_loc = "6,6"
			C.screen+=src
	White
		icon_state="white"
		New(client/C)
			screen_loc = "6,4"
			C.screen+=src

/*
There, now we have the black and white blocks made.
I have them set up to spawn when you choose this
section upon login.


2. How do you make the cursor move?
____________________________________

This is the key to making these selection huds work
as your own switch. I'll take this step by step
because it might get complicated.

The first thing we need to do is set a variable.
This variable will stand for the place on the client's
screen that you want the cursor to spawn when it's made.
There is a variable for the X and the Y.
*/

mob/var
	setx=4
	sety=6

/*

Don't worry, I'm about to explain what these do.

I have these preset to have X at 4 and Y at 6. I
think that is fairly obvious. X is at 4 so that the
cursor is 2 tiles away from the blocks. The starting
Y point is at 6 and will change when you move it
with the Up and Down arrow keys.

Now we make the cursor object and put these variables
to work.
*/

obj
	Cursor
		icon='Huds.dmi'
		icon_state="cursor"
		New(client/C)
			screen_loc="[usr.setx],[usr.sety]"
			C.screen+=src

/*
As you can plainly see, I made the screen_loc points
be the client's setx and sety variables. This means
that when the cursor spawns, it will be placed at
whatever point those variables tell it to be at.
Here is where the fun starts:

We can now use the North and South client verbs to
change the setx and sety variables. You should know
how to edit those verbs.
*/
mob/var/Selection="" //This is your choice. Black, or White.

client
	North()
		if(usr.Selection=="")
			return
			/*
			I return this to make sure that you can't control
			the sety unless you are selecting something.
			The Login proc automatically puts your
			selection at Black to ensure that this works.
			*/

		if(usr.sety==6)
			return
			/*
			I return it when it's at 6 because there is
			nothing above 6 for North to go to.
			*/
		else
			usr.sety+=2
			if(usr.sety==6)
				usr.Selection="Black"
			if(usr.sety==4)
				usr.Selection="White"
			for(var/obj/Cursor/A in usr.client.screen)
				del(A)
			new/obj/Cursor(usr.client)
			/*
			This then adds 2 to sety and checks if the Selection
			should be Black or White. Then it deletes and
			respawns the cursor. If there are more than
			two selections, this system is necessary.

			I will then do pretty much the same for South.
			*/
	South()
		if(usr.Selection=="")
			return
		if(usr.sety==4)
			return
		else
			usr.sety-=2
			if(usr.sety==6)
				usr.Selection="Black"
			if(usr.sety==4)
				usr.Selection="White"
			for(var/obj/Cursor/A in usr.client.screen)
				del(A)
			new/obj/Cursor(usr.client)

/*
That was a bit more code than you're probably
used to me giving you at once, so I'll break
it down for you a little.

Most of it is explained up there, but I'll
explain the more important cursor stuff like
this for example:

for(var/obj/Cursor/A in usr.client.screen)
	del(A)
new/obj/Cursor(usr.client)

This line of code here is what refreshes the
cursor when you move with the arrow keys.
By refresh I mean that it deletes the cursor,
then respawns it.

if(usr.sety==6)
	usr.Selection="Black"
if(usr.sety==4)
	usr.Selection="White"

This is what decides what the selection is up there.
If you have alot of selections to choose from, this
can be a tedious thing to do, but it has to be done
in order to define what to do at each selection.


3. How do I select a choice now?
__________________________________

Now that you have it set at a certain selection,
creating the verb to select a choice is easy.

All you need to do here is create a verb to do
something in response to what your Selection
variable is. Once that's done, set it to a
macro in your interface and you're done!

*/

mob/verb/Select()
	if(usr.Selection=="Black")
		alert("What a cool looking black square!")
	if(usr.Selection=="White")
		alert("What a cool looking white square!")

/*
With that verb made, I have set the macro to
Enter in the interface.


That is everything that I have to teach you here in Conquer
Huds! I hope that you have learned alot through this. Be sure
to expand upon this and use it in as many ways as you can think
of in order to expand your knowledge.

Study it carefully! Don't just copy and paste!

-Fugsnarf

*/




